@@ -60,8 +60,6 @@
 #include <private/qitem_p.h>
 #include <private/qnamepool_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -399,6 +397,4 @@ Q_DECLARE_TYPEINFO(QPatternist::AccelTree::BasicNodeData, Q_MOVABLE_TYPE);
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
