@@ -57,8 +57,6 @@
 #include <QtCore/QSharedData>
 #include <QtCore/QString>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -335,6 +333,4 @@ qint64 QAbstractXmlForwardIterator<T>::sizeHint() const
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
