@@ -46,8 +46,6 @@
 #include <QtCore/QScopedPointer>
 #include <QtXmlPatterns/QXmlNodeModelIndex>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -101,6 +99,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
