@@ -54,7 +54,6 @@
 
 #include <private/qresourceloader_p.h>
 
-QT_BEGIN_HEADER
 QT_BEGIN_NAMESPACE
 
 template<typename T> class QSet;
@@ -83,6 +82,4 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
-
 #endif
