@@ -44,8 +44,6 @@
 
 #include <QtXmlPatterns/QXmlSerializer>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -88,6 +86,4 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
