@@ -46,7 +46,6 @@
 #include <QtCore/QScopedPointer>
 #include <QtXmlPatterns/qtxmlpatternsglobal.h>
 
-QT_BEGIN_HEADER
 QT_BEGIN_NAMESPACE
 
 
@@ -72,6 +71,5 @@ private:
 };
 
 QT_END_NAMESPACE
-QT_END_HEADER
 
 #endif
