@@ -64,8 +64,6 @@
 
 #include <QtNetwork/QNetworkAccessManager>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QXmlSchemaValidatorPrivate
@@ -126,6 +124,4 @@ public:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
