@@ -60,8 +60,6 @@
 #include <private/qpatternistlocale_p.h>
 #include <private/qreportcontext_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -207,6 +205,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
