@@ -57,8 +57,6 @@
 #include <private/qitem_p.h>
 #include <private/qatomictypedispatch_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QString;
@@ -218,6 +216,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
