@@ -55,8 +55,6 @@
 #include <private/qabstractduration_p.h>
 #include <private/qitem_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -149,6 +147,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
