@@ -57,8 +57,6 @@
 #include <private/qpatternistlocale_p.h>
 #include <private/qvalidationerror_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -395,6 +393,8 @@ namespace QPatternist
              * reason get a linker error with GCC. Using this temporary
              * variable solves it. */
             const StorageType minimum = minInclusive;
+            // MSVC2010 complains that this is initialised but not referenced.
+            Q_UNUSED(minimum)
 
             if((limitsUsage & LimitUpwards) &&
                num > maxInclusive)
@@ -619,6 +619,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
