@@ -72,8 +72,6 @@
  * @short Qt's base class for reference counting.
  */
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 template<typename T> class QList;
@@ -528,6 +526,4 @@ Q_DECLARE_TYPEINFO(QPatternist::AtomicValue, Q_MOVABLE_TYPE);
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
