@@ -56,8 +56,6 @@
 #include "qabstractxmlreceiver.h"
 #include <private/qautoptr_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -106,6 +104,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
