@@ -57,8 +57,6 @@
 #include <private/qsequencetype_p.h>
 #include <private/qsourcelocationreflection_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QUrl;
@@ -315,6 +313,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
