@@ -58,8 +58,6 @@
 #include <private/qfunctionfactory_p.h>
 #include <private/qschematypefactory_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -142,6 +140,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
