@@ -59,8 +59,6 @@
 #include <private/qfunctionfactory_p.h>
 #include <private/qschematypefactory_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -194,6 +192,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
