@@ -59,8 +59,6 @@
 #include <private/qnamepool_p.h>
 #include <QXmlName>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QAbstractMessageHandler;
@@ -2459,6 +2457,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
