@@ -59,8 +59,6 @@
 #include <private/qreportcontext_p.h>
 #include <private/qresourceloader_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QUrl;
@@ -294,6 +292,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
