@@ -56,7 +56,6 @@
 #include <private/qcalltargetdescription_p.h>
 #include <QXmlName>
 
-QT_BEGIN_HEADER
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -106,6 +105,5 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
 
 #endif
