@@ -56,8 +56,6 @@
 #include <private/qexpression_p.h>
 #include "qabstractxmlreceiver.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -112,6 +110,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
