@@ -64,8 +64,6 @@
 #include <private/qsourcelocationreflection_p.h>
 #include <private/qstaticcontext_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 template<typename T> class QList;
@@ -904,6 +902,4 @@ Q_DECLARE_TYPEINFO(QPatternist::Expression::Ptr, Q_MOVABLE_TYPE);
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
