@@ -56,8 +56,6 @@
 #include <private/qsequencetype_p.h>
 #include <QXmlName>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -134,6 +132,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
