@@ -56,8 +56,6 @@
 #include <private/qpaircontainer_p.h>
 #include <private/qcomparisonplatform_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -131,6 +129,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
