@@ -55,8 +55,6 @@
 #include <private/qpaircontainer_p.h>
 #include <private/qvariabledeclaration_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -104,6 +102,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
