@@ -56,8 +56,6 @@
 #include <private/qpatternistlocale_p.h>
 #include <private/qxmlutils_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -149,6 +147,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
