@@ -55,8 +55,6 @@
 #include <private/qorderby_p.h>
 #include <private/qunlimitedcontainer_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -131,6 +129,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
