@@ -55,7 +55,6 @@
 #include <private/qvariabledeclaration_p.h>
 #include <private/qemptycontainer_p.h>
 
-QT_BEGIN_HEADER
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -100,6 +99,5 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
 
 #endif
