@@ -52,8 +52,6 @@
 #ifndef Patternist_UnaryExpression_H
 #define Patternist_UnaryExpression_H
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 #include <private/qarithmeticexpression_p.h>
@@ -109,6 +107,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
