@@ -55,8 +55,6 @@
 #include <private/qabstractfunctionfactory_p.h>
 #include <private/qschematypefactory_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -90,6 +88,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
