@@ -65,8 +65,6 @@
  * @ingroup Patternist_functions
  */
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -162,6 +160,5 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
 
 #endif
