@@ -54,8 +54,6 @@
 
 #include <private/qfunctioncall_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -89,6 +87,4 @@ statEnv |-  (FN-URI,"trace")(Type) : prime(Type) * quantifier(Type)
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
