@@ -55,8 +55,6 @@
 #include <private/qschematypefactory_p.h>
 #include <private/qstaticnamespacescontainer_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -87,6 +85,4 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
-
 #endif
