@@ -54,8 +54,6 @@
 
 #include <private/qstaticbaseuricontainer_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 namespace QPatternist
 {
@@ -78,6 +76,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
