@@ -58,8 +58,6 @@
 #include <private/qdynamiccontext_p.h>
 #include <private/qitem_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -124,6 +122,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
