@@ -63,8 +63,6 @@
 #include <private/qquerytransformparser_p.h>
 #include <private/qvalidate_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 template<typename T> class QQueue;
@@ -164,6 +162,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
