@@ -61,8 +61,6 @@
 #include <private/qtokenizer_p.h>
 #include <private/qxslttokenlookup_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -476,6 +474,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
