@@ -55,8 +55,6 @@
 #include <private/qprojectedexpression_p.h>
 #include "qabstractxmlreceiver.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -102,6 +100,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
