@@ -60,8 +60,6 @@
 #include <QtCore/QStack>
 #include <QtCore/QXmlStreamNamespaceDeclarations>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -168,6 +166,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
