@@ -58,8 +58,6 @@
 
 #include <QtCore/QList>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -241,6 +239,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
