@@ -57,8 +57,6 @@
 #include <private/qderivedstring_p.h>
 #include <private/qnamedschemacomponent_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -132,6 +130,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
