@@ -57,8 +57,6 @@
 #include <private/qxsdschemacontext_p.h>
 #include <private/qxsdwildcard_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -101,6 +99,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
