@@ -56,8 +56,6 @@
 
 #include <QtXmlPatterns/QSourceLocation>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -140,6 +138,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
