@@ -73,8 +73,6 @@
 #include <QtCore/QXmlStreamReader>
 #include <QtXmlPatterns/QXmlNamePool>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -734,6 +732,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
