@@ -68,8 +68,6 @@
 
 #include <QtCore/QExplicitlySharedDataPointer>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -573,6 +571,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
