@@ -55,8 +55,6 @@
 #include <private/qnamedschemacomponent_p.h>
 #include <private/qxsdannotated_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -109,6 +107,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
