@@ -58,8 +58,6 @@
 #include <private/qsourcelocationreflection_p.h>
 #include <private/qxsdschemacontext_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QXmlQuery;
@@ -184,6 +182,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
