@@ -59,8 +59,6 @@
 
 #include <QtCore/QStack>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QXmlQuery;
@@ -291,6 +289,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
