@@ -59,8 +59,6 @@
 #include <private/qatomictypedispatch_p.h>
 #include <private/qitemtype_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -155,6 +153,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
