@@ -56,8 +56,6 @@
 #include <private/qatomiccomparatorlocators_p.h>
 #include <private/qbuiltinatomictype_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -784,6 +782,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
