@@ -56,8 +56,6 @@
 #include <private/qanynodetype_p.h>
 #include <private/qbuiltintypes_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -105,6 +103,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
