@@ -60,8 +60,6 @@
 #include <private/qnumerictype_p.h>
 #include <private/quntyped_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -168,7 +166,5 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 
