@@ -55,8 +55,6 @@
 #include <private/qatomictype_p.h>
 #include <private/qsequencetype_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -130,6 +128,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
