@@ -58,8 +58,6 @@
 #include <private/qitemtype_p.h>
 #include <private/qschematype_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -97,6 +95,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
