@@ -57,8 +57,6 @@
 #include <private/qnamespaceresolver_p.h>
 #include <private/qitem_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -86,6 +84,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
