@@ -58,8 +58,6 @@
 #include "qabstractxmlreceiver.h"
 #include <private/qsourcelocationreflection_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -122,6 +120,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
