@@ -46,8 +46,6 @@
 #include "qabstractmessagehandler.h"
 
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 template<typename T> class QList;
@@ -143,7 +141,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
