@@ -48,8 +48,6 @@
 #include <QPair>
 #include <QString>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternistSDK
@@ -74,7 +72,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
