@@ -50,8 +50,6 @@
 #include <private/qresourceloader_p.h>
 #include <private/qexternalvariableloader_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternistSDK
@@ -131,7 +129,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
