@@ -63,8 +63,6 @@
  * @see <a href="http://www.w3.org/XML/Query/test-suite/">XML Query Test Suite</a>
  * @author Frans Englich <frans.englich@nokia.com>
  */
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternistSDK
@@ -122,7 +120,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
