@@ -52,7 +52,22 @@
 
 using namespace QPatternistSDK;
 
-QNetworkAccessManager s_networkManager;
+static QNetworkAccessManager *s_networkAccessManager = 0;
+
+static void cleanupNetworkAccessManager()
+{
+    delete s_networkAccessManager;
+    s_networkAccessManager = 0;
+
+}
+static QNetworkAccessManager *networkAccessManager()
+{
+    if (!s_networkAccessManager) {
+        s_networkAccessManager = new QNetworkAccessManager;
+        qAddPostRoutine(cleanupNetworkAccessManager);
+    }
+    return s_networkAccessManager;
+}
 
 TestSuiteHandler::TestSuiteHandler(const QUrl &catalogFile,
                                    const bool useEList) : m_ts(0)
@@ -275,7 +290,7 @@ bool TestSuiteHandler::endElement(const QString &namespaceURI,
     }
     else if(localName == QLatin1String("sources"))
     {
-        const QPatternist::NetworkAccessDelegator::Ptr networkDelegator(new QPatternist::NetworkAccessDelegator(&s_networkManager, &s_networkManager));
+        const QPatternist::NetworkAccessDelegator::Ptr networkDelegator(new QPatternist::NetworkAccessDelegator(networkAccessManager(), networkAccessManager()));
 
         m_resourceLoader = QPatternist::ResourceLoader::Ptr(new QPatternist::AccelTreeResourceLoader(Global::namePool(),
                                                                                                      networkDelegator));
