@@ -50,8 +50,6 @@
 #include "TestSuite.h"
 #include "XQTSTestCase.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternistSDK
@@ -163,7 +161,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
